# coding: utf-8

# flake8: noqa

"""
    Vayu API

    The Vayu API is a RESTful API that allows you to submit events for processing and storage & manage billing related entities.           The API is secured using the Bearer Authentication scheme with JWT tokens.           To obtain a JWT token, please contact Vayu at team@withvayu.com

    The version of the OpenAPI document: 1.0.0
    Contact: dev@withvayu.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from openapi_client.api.auth_api import AuthApi
from openapi_client.api.contracts_api import ContractsApi
from openapi_client.api.customers_api import CustomersApi
from openapi_client.api.events_api import EventsApi
from openapi_client.api.invoices_api import InvoicesApi
from openapi_client.api.meters_api import MetersApi
from openapi_client.api.plans_api import PlansApi

# import ApiClient
from openapi_client.api_response import ApiResponse
from openapi_client.api_client import ApiClient
from openapi_client.configuration import Configuration
from openapi_client.exceptions import OpenApiException
from openapi_client.exceptions import ApiTypeError
from openapi_client.exceptions import ApiValueError
from openapi_client.exceptions import ApiKeyError
from openapi_client.exceptions import ApiAttributeError
from openapi_client.exceptions import ApiException

# import models into sdk package
from openapi_client.models.aggregation_method import AggregationMethod
from openapi_client.models.aggregation_operator import AggregationOperator
from openapi_client.models.billing_interval import BillingInterval
from openapi_client.models.condition import Condition
from openapi_client.models.create_contract_request_schema import CreateContractRequestSchema
from openapi_client.models.create_contract_response_schema import CreateContractResponseSchema
from openapi_client.models.create_customer_request_schema import CreateCustomerRequestSchema
from openapi_client.models.create_customer_response_schema import CreateCustomerResponseSchema
from openapi_client.models.create_customer_response_schema_customer import CreateCustomerResponseSchemaCustomer
from openapi_client.models.criterion import Criterion
from openapi_client.models.criterion_operator import CriterionOperator
from openapi_client.models.delete_contract_response_schema import DeleteContractResponseSchema
from openapi_client.models.delete_contract_response_schema_contract import DeleteContractResponseSchemaContract
from openapi_client.models.delete_customer_response_schema import DeleteCustomerResponseSchema
from openapi_client.models.delete_customer_response_schema_customer import DeleteCustomerResponseSchemaCustomer
from openapi_client.models.delete_event_by_ref_id_response_schema import DeleteEventByRefIdResponseSchema
from openapi_client.models.delete_event_by_ref_id_response_schema_event import DeleteEventByRefIdResponseSchemaEvent
from openapi_client.models.delete_meter_response_schema import DeleteMeterResponseSchema
from openapi_client.models.delete_meter_response_schema_meter import DeleteMeterResponseSchemaMeter
from openapi_client.models.delete_plan_response_schema import DeletePlanResponseSchema
from openapi_client.models.delete_plan_response_schema_plan import DeletePlanResponseSchemaPlan
from openapi_client.models.event import Event
from openapi_client.models.events_dry_run_request_schema import EventsDryRunRequestSchema
from openapi_client.models.events_dry_run_response_schema_inner import EventsDryRunResponseSchemaInner
from openapi_client.models.events_dry_run_response_schema_inner_event import EventsDryRunResponseSchemaInnerEvent
from openapi_client.models.events_dry_run_response_schema_inner_meter_with_values_inner import EventsDryRunResponseSchemaInnerMeterWithValuesInner
from openapi_client.models.filter import Filter
from openapi_client.models.get_contract_response_schema import GetContractResponseSchema
from openapi_client.models.get_contract_response_schema_contract import GetContractResponseSchemaContract
from openapi_client.models.get_customer_response_schema import GetCustomerResponseSchema
from openapi_client.models.get_event_by_ref_id_response_schema import GetEventByRefIdResponseSchema
from openapi_client.models.get_event_by_ref_id_response_schema_event import GetEventByRefIdResponseSchemaEvent
from openapi_client.models.get_invoice_response_schema import GetInvoiceResponseSchema
from openapi_client.models.get_invoice_response_schema_invoice import GetInvoiceResponseSchemaInvoice
from openapi_client.models.get_invoice_response_schema_invoice_line_items_inner import GetInvoiceResponseSchemaInvoiceLineItemsInner
from openapi_client.models.get_meter_response_schema import GetMeterResponseSchema
from openapi_client.models.get_meter_response_schema_meter import GetMeterResponseSchemaMeter
from openapi_client.models.get_plan_response_schema import GetPlanResponseSchema
from openapi_client.models.get_plan_response_schema_plan import GetPlanResponseSchemaPlan
from openapi_client.models.list_contracts_response_schema import ListContractsResponseSchema
from openapi_client.models.list_customers_response_schema import ListCustomersResponseSchema
from openapi_client.models.list_invoices_response_schema import ListInvoicesResponseSchema
from openapi_client.models.list_meters_response_schema import ListMetersResponseSchema
from openapi_client.models.list_plans_response_schema import ListPlansResponseSchema
from openapi_client.models.login_request_schema import LoginRequestSchema
from openapi_client.models.login_response_schema import LoginResponseSchema
from openapi_client.models.period import Period
from openapi_client.models.plan_billing_data import PlanBillingData
from openapi_client.models.plan_status import PlanStatus
from openapi_client.models.plan_type import PlanType
from openapi_client.models.query_events_response_schema import QueryEventsResponseSchema
from openapi_client.models.query_events_response_schema_events_inner import QueryEventsResponseSchemaEventsInner
from openapi_client.models.send_events_request_schema import SendEventsRequestSchema
from openapi_client.models.send_events_response_schema import SendEventsResponseSchema
from openapi_client.models.send_events_response_schema_invalid_events_inner import SendEventsResponseSchemaInvalidEventsInner
from openapi_client.models.update_customer_request_schema import UpdateCustomerRequestSchema
from openapi_client.models.update_customer_response_schema import UpdateCustomerResponseSchema
from openapi_client.models.update_meter_request_schema import UpdateMeterRequestSchema
from openapi_client.models.update_meter_response_schema import UpdateMeterResponseSchema



from datetime import datetime
from typing import List

from openapi_client.api.events_api import EventsApi
from openapi_client.api_client import ApiClient
from openapi_client.models.event import Event
from openapi_client.models.send_events_request_schema import \
    SendEventsRequestSchema


class EventsClient:
    __events_client: EventsApi = None

    def __init__(self, api_client: ApiClient):
        self.__events_client = EventsApi(api_client)

    def query(
        self,
        start_time: datetime,
        end_time: datetime,
        event_name: str,
        cursor: str = None,
        limit: int = None
    ):
        return self.__events_client.query_events(
            start_time=start_time,
            end_time=end_time,
            event_name=event_name,
            cursor=cursor,
            limit=limit
        )

    def get(self, ref: str):
        return self.__events_client.get_event_by_ref_id(ref)

    def delete(self, ref: str):
        return self.__events_client.delete_event_by_ref_id(ref)

    def send(self, events: List[Event]):
        send_events_request_schema = SendEventsRequestSchema(events)

        return self.__events_client.send_events(send_events_request_schema)

    def dry_run(self, events: List[Event]):
        send_events_request_schema = SendEventsRequestSchema(events)

        return self.__events_client.send_events_dry_run(send_events_request_schema)


# coding: utf-8

"""
    Vayu API

    The Vayu API is a RESTful API that allows you to submit events for processing and storage & manage billing related entities.           The API is secured using the Bearer Authentication scheme with JWT tokens.           To obtain a JWT token, please contact Vayu at team@withvayu.com

    The version of the OpenAPI document: 1.0.0
    Contact: dev@withvayu.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictStr
from typing import List, Optional, Union
from typing_extensions import Annotated
from openapi_client.models.delete_event_by_ref_id_response_schema import DeleteEventByRefIdResponseSchema
from openapi_client.models.events_dry_run_request_schema import EventsDryRunRequestSchema
from openapi_client.models.events_dry_run_response_schema_inner import EventsDryRunResponseSchemaInner
from openapi_client.models.get_event_by_ref_id_response_schema import GetEventByRefIdResponseSchema
from openapi_client.models.query_events_response_schema import QueryEventsResponseSchema
from openapi_client.models.send_events_request_schema import SendEventsRequestSchema
from openapi_client.models.send_events_response_schema import SendEventsResponseSchema

from openapi_client.api_client import ApiClient, RequestSerialized
from openapi_client.api_response import ApiResponse
from openapi_client.rest import RESTResponseType


class EventsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete_event_by_ref_id(
        self,
        ref_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DeleteEventByRefIdResponseSchema:
        """Delete an event by refId

        Use this endpoint to remove a specific event using its reference ID.

        :param ref_id: (required)
        :type ref_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_event_by_ref_id_serialize(
            ref_id=ref_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DeleteEventByRefIdResponseSchema",
            '400': None,
            '401': None,
            '404': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_event_by_ref_id_with_http_info(
        self,
        ref_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DeleteEventByRefIdResponseSchema]:
        """Delete an event by refId

        Use this endpoint to remove a specific event using its reference ID.

        :param ref_id: (required)
        :type ref_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_event_by_ref_id_serialize(
            ref_id=ref_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DeleteEventByRefIdResponseSchema",
            '400': None,
            '401': None,
            '404': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_event_by_ref_id_without_preload_content(
        self,
        ref_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete an event by refId

        Use this endpoint to remove a specific event using its reference ID.

        :param ref_id: (required)
        :type ref_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_event_by_ref_id_serialize(
            ref_id=ref_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DeleteEventByRefIdResponseSchema",
            '400': None,
            '401': None,
            '404': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_event_by_ref_id_serialize(
        self,
        ref_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if ref_id is not None:
            _path_params['refId'] = ref_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuthorizer'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/events/{refId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_event_by_ref_id(
        self,
        ref_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetEventByRefIdResponseSchema:
        """Get event by refId

        Use this endpoint to get a specific event using its reference ID.

        :param ref_id: (required)
        :type ref_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_event_by_ref_id_serialize(
            ref_id=ref_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetEventByRefIdResponseSchema",
            '400': None,
            '401': None,
            '404': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_event_by_ref_id_with_http_info(
        self,
        ref_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetEventByRefIdResponseSchema]:
        """Get event by refId

        Use this endpoint to get a specific event using its reference ID.

        :param ref_id: (required)
        :type ref_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_event_by_ref_id_serialize(
            ref_id=ref_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetEventByRefIdResponseSchema",
            '400': None,
            '401': None,
            '404': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_event_by_ref_id_without_preload_content(
        self,
        ref_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get event by refId

        Use this endpoint to get a specific event using its reference ID.

        :param ref_id: (required)
        :type ref_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_event_by_ref_id_serialize(
            ref_id=ref_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetEventByRefIdResponseSchema",
            '400': None,
            '401': None,
            '404': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_event_by_ref_id_serialize(
        self,
        ref_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if ref_id is not None:
            _path_params['refId'] = ref_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuthorizer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/events/{refId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def query_events(
        self,
        start_time: datetime,
        end_time: datetime,
        event_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        limit: Optional[Union[Annotated[float, Field(le=1000, strict=True)], Annotated[int, Field(le=1000, strict=True)]]] = None,
        cursor: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> QueryEventsResponseSchema:
        """Query events by timestamp period and optional event name

        Fetch events occurring within a specified timestamp range. An optional event name can be provided to further filter the events.

        :param start_time: (required)
        :type start_time: datetime
        :param end_time: (required)
        :type end_time: datetime
        :param event_name:
        :type event_name: str
        :param limit:
        :type limit: float
        :param cursor:
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._query_events_serialize(
            start_time=start_time,
            end_time=end_time,
            event_name=event_name,
            limit=limit,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "QueryEventsResponseSchema",
            '400': None,
            '401': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def query_events_with_http_info(
        self,
        start_time: datetime,
        end_time: datetime,
        event_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        limit: Optional[Union[Annotated[float, Field(le=1000, strict=True)], Annotated[int, Field(le=1000, strict=True)]]] = None,
        cursor: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[QueryEventsResponseSchema]:
        """Query events by timestamp period and optional event name

        Fetch events occurring within a specified timestamp range. An optional event name can be provided to further filter the events.

        :param start_time: (required)
        :type start_time: datetime
        :param end_time: (required)
        :type end_time: datetime
        :param event_name:
        :type event_name: str
        :param limit:
        :type limit: float
        :param cursor:
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._query_events_serialize(
            start_time=start_time,
            end_time=end_time,
            event_name=event_name,
            limit=limit,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "QueryEventsResponseSchema",
            '400': None,
            '401': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def query_events_without_preload_content(
        self,
        start_time: datetime,
        end_time: datetime,
        event_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        limit: Optional[Union[Annotated[float, Field(le=1000, strict=True)], Annotated[int, Field(le=1000, strict=True)]]] = None,
        cursor: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Query events by timestamp period and optional event name

        Fetch events occurring within a specified timestamp range. An optional event name can be provided to further filter the events.

        :param start_time: (required)
        :type start_time: datetime
        :param end_time: (required)
        :type end_time: datetime
        :param event_name:
        :type event_name: str
        :param limit:
        :type limit: float
        :param cursor:
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._query_events_serialize(
            start_time=start_time,
            end_time=end_time,
            event_name=event_name,
            limit=limit,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "QueryEventsResponseSchema",
            '400': None,
            '401': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _query_events_serialize(
        self,
        start_time,
        end_time,
        event_name,
        limit,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if start_time is not None:
            if isinstance(start_time, datetime):
                _query_params.append(
                    (
                        'startTime',
                        start_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('startTime', start_time))
            
        if end_time is not None:
            if isinstance(end_time, datetime):
                _query_params.append(
                    (
                        'endTime',
                        end_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('endTime', end_time))
            
        if event_name is not None:
            
            _query_params.append(('eventName', event_name))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuthorizer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/events',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def send_events(
        self,
        send_events_request_schema: Annotated[SendEventsRequestSchema, Field(description="An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SendEventsResponseSchema:
        """Submit a batch of events for ingestion

        Use this endpoint to send an array of events for processing and storage. Make sure to comply with the request schema for each event.

        :param send_events_request_schema: An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB (required)
        :type send_events_request_schema: SendEventsRequestSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_events_serialize(
            send_events_request_schema=send_events_request_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SendEventsResponseSchema",
            '400': None,
            '401': None,
            '413': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def send_events_with_http_info(
        self,
        send_events_request_schema: Annotated[SendEventsRequestSchema, Field(description="An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SendEventsResponseSchema]:
        """Submit a batch of events for ingestion

        Use this endpoint to send an array of events for processing and storage. Make sure to comply with the request schema for each event.

        :param send_events_request_schema: An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB (required)
        :type send_events_request_schema: SendEventsRequestSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_events_serialize(
            send_events_request_schema=send_events_request_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SendEventsResponseSchema",
            '400': None,
            '401': None,
            '413': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def send_events_without_preload_content(
        self,
        send_events_request_schema: Annotated[SendEventsRequestSchema, Field(description="An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Submit a batch of events for ingestion

        Use this endpoint to send an array of events for processing and storage. Make sure to comply with the request schema for each event.

        :param send_events_request_schema: An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB (required)
        :type send_events_request_schema: SendEventsRequestSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_events_serialize(
            send_events_request_schema=send_events_request_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SendEventsResponseSchema",
            '400': None,
            '401': None,
            '413': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _send_events_serialize(
        self,
        send_events_request_schema,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if send_events_request_schema is not None:
            _body_params = send_events_request_schema


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuthorizer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/events',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def send_events_dry_run(
        self,
        events_dry_run_request_schema: Annotated[EventsDryRunRequestSchema, Field(description="An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[EventsDryRunResponseSchemaInner]:
        """Submit a batch of events for testing

        Use this endpoint to send an array of events for processing. Make sure to comply with the request schema for each event. NOTE: this is a dry run and will not result in actual storage of the events.

        :param events_dry_run_request_schema: An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB (required)
        :type events_dry_run_request_schema: EventsDryRunRequestSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_events_dry_run_serialize(
            events_dry_run_request_schema=events_dry_run_request_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[EventsDryRunResponseSchemaInner]",
            '400': None,
            '401': None,
            '413': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def send_events_dry_run_with_http_info(
        self,
        events_dry_run_request_schema: Annotated[EventsDryRunRequestSchema, Field(description="An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[EventsDryRunResponseSchemaInner]]:
        """Submit a batch of events for testing

        Use this endpoint to send an array of events for processing. Make sure to comply with the request schema for each event. NOTE: this is a dry run and will not result in actual storage of the events.

        :param events_dry_run_request_schema: An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB (required)
        :type events_dry_run_request_schema: EventsDryRunRequestSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_events_dry_run_serialize(
            events_dry_run_request_schema=events_dry_run_request_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[EventsDryRunResponseSchemaInner]",
            '400': None,
            '401': None,
            '413': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def send_events_dry_run_without_preload_content(
        self,
        events_dry_run_request_schema: Annotated[EventsDryRunRequestSchema, Field(description="An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Submit a batch of events for testing

        Use this endpoint to send an array of events for processing. Make sure to comply with the request schema for each event. NOTE: this is a dry run and will not result in actual storage of the events.

        :param events_dry_run_request_schema: An array of events following the EventInput schema. This request body should be included in the PUT request to '/events'       Up to 1000 events or a total payload max size of 256KB (required)
        :type events_dry_run_request_schema: EventsDryRunRequestSchema
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_events_dry_run_serialize(
            events_dry_run_request_schema=events_dry_run_request_schema,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[EventsDryRunResponseSchemaInner]",
            '400': None,
            '401': None,
            '413': None,
            '429': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _send_events_dry_run_serialize(
        self,
        events_dry_run_request_schema,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if events_dry_run_request_schema is not None:
            _body_params = events_dry_run_request_schema


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuthorizer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/events/dry-run',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





from openapi_client.api.invoices_api import InvoicesApi
from openapi_client.api_client import ApiClient


class InvoicesClient:
    __invoices_client: InvoicesApi = None

    def __init__(self, api_client: ApiClient):
        self.__invoices_client = InvoicesApi(api_client)

    def get(self, invoice_id: str):
        return self.__invoices_client.get_invoice(invoice_id)
    
    def list(self, limit: int = None, cursor: int = None):
        return self.__invoices_client.list_invoices(limit=limit, cursor=cursor)


# coding: utf-8

"""
    Vayu API

    The Vayu API is a RESTful API that allows you to submit events for processing and storage & manage billing related entities.           The API is secured using the Bearer Authentication scheme with JWT tokens.           To obtain a JWT token, please contact Vayu at team@withvayu.com

    The version of the OpenAPI document: 1.0.0
    Contact: dev@withvayu.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from openapi_client.models.aggregation_method import AggregationMethod
from openapi_client.models.filter import Filter
from typing import Optional, Set
from typing_extensions import Self

class DeleteMeterResponseSchemaMeter(BaseModel):
    """
    DeleteMeterResponseSchemaMeter
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The name of the meter")
    event_name: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The name of the event that the meter is tracking.", alias="eventName")
    aggregation_method: AggregationMethod = Field(alias="aggregationMethod")
    filter: Optional[Filter] = None
    id: Annotated[str, Field(strict=True)]
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: StrictStr = Field(alias="deletedAt")
    __properties: ClassVar[List[str]] = ["name", "eventName", "aggregationMethod", "filter", "id", "createdAt", "updatedAt", "deletedAt"]

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[0-9a-fA-F]{24}$", value):
            raise ValueError(r"must validate the regular expression /^[0-9a-fA-F]{24}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DeleteMeterResponseSchemaMeter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of aggregation_method
        if self.aggregation_method:
            _dict['aggregationMethod'] = self.aggregation_method.to_dict()
        # override the default output from pydantic by calling `to_dict()` of filter
        if self.filter:
            _dict['filter'] = self.filter.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DeleteMeterResponseSchemaMeter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "eventName": obj.get("eventName"),
            "aggregationMethod": AggregationMethod.from_dict(obj["aggregationMethod"]) if obj.get("aggregationMethod") is not None else None,
            "filter": Filter.from_dict(obj["filter"]) if obj.get("filter") is not None else None,
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "deletedAt": obj.get("deletedAt")
        })
        return _obj





from openapi_client.api.plans_api import PlansApi
from openapi_client.api_client import ApiClient


class PlansClient:
    __plans_client: PlansApi = None

    def __init__(self, api_client: ApiClient):
        self.__plans_client = PlansApi(api_client)

    def get(self, plan_id: str):
        return self.__plans_client.get_plan(plan_id)
    
    def list(self, limit: int = None, cursor: int = None):
        return self.__plans_client.list_plans(limit=limit, cursor=cursor)

    def delete(self, id: str):
        return self.__plans_client.delete_plan(id)


# coding: utf-8

"""
    Vayu API

    The Vayu API is a RESTful API that allows you to submit events for processing and storage & manage billing related entities.           The API is secured using the Bearer Authentication scheme with JWT tokens.           To obtain a JWT token, please contact Vayu at team@withvayu.com

    The version of the OpenAPI document: 1.0.0
    Contact: dev@withvayu.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BillingInterval(str, Enum):
    """
    BillingInterval
    """

    """
    allowed enum values
    """
    MONTHLY = 'Monthly'
    BIMONTHLY = 'BiMonthly'
    QUARTERLY = 'Quarterly'
    SIXMONTHS = 'SixMonths'
    YEARLY = 'Yearly'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BillingInterval from a JSON string"""
        return cls(json.loads(json_str))





from typing import List

from openapi_client.api.meters_api import MetersApi
from openapi_client.api_client import ApiClient
from openapi_client.models.aggregation_method import AggregationMethod
from openapi_client.models.filter import Filter
from openapi_client.models.update_meter_request_schema import \
    UpdateMeterRequestSchema


class MetersClient:
    __meters_client: MetersApi = None

    def __init__(self, api_client: ApiClient):
        self.__meters_client = MetersApi(api_client)

    def get(self, meter_id: str):
        return self.__meters_client.get_meter(meter_id)
    
    def list(self, limit: int = None, cursor: int = None):
        return self.__meters_client.list_meters(limit=limit, cursor=cursor)

    def update(
        self,
        id: str,
        name: str = None,
        event_name: str = None,
        aggregation_method: AggregationMethod = None,
        filter: Filter = None,
    ):
        update_meter_request = UpdateMeterRequestSchema(
            name=name,
            eventName=event_name,
            aggregationMethod=aggregation_method,
            filter=filter
        )

        return self.__meters_client.update_meter(id, update_meter_request)

    def delete(self, id: str):
        return self.__meters_client.delete_meter(id)
        






    # name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The name of the meter")
    # event_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The name of the event that the meter is tracking.", alias="eventName")
    # aggregation_method: Optional[EventsDryRunResponseSchemaInnerMeterWithValuesInnerAggregationMethod] = Field(default=None, alias="aggregationMethod")
    # filter: Optional[Filter] = None


from entity_clients.contracts_client import ContractsClient
from entity_clients.customers_client import CustomersClient
from entity_clients.events_client import EventsClient
from entity_clients.invoices_client import InvoicesClient
from entity_clients.meters_client import MetersClient
from entity_clients.plans_client import PlansClient
from openapi_client.api.auth_api import AuthApi
from openapi_client.api_client import ApiClient
from openapi_client.configuration import Configuration
from openapi_client.models.aggregation_method import AggregationMethod
from openapi_client.models.login_request_schema import LoginRequestSchema
from vayu_consts import VAYU_URL


class Vayu:
    __access_token: str = None
    __host: str

    def __init__(self, api_key: str, host: str = VAYU_URL):
        self.__host = host
        self.__login(api_key)
    

    @property
    def __private_api_client(self):
        configuration = Configuration(host=self.__host, api_key=self.__access_token)
        return ApiClient(configuration, header_name='Authorization', header_value=f'Bearer {self.__access_token}')

    @property
    def __public_api_client(self):
        configuration = Configuration(host=self.__host)
        
        return ApiClient(configuration)
    

    @property
    def customers(self)->CustomersClient:
        return CustomersClient(self.__private_api_client)

    @property
    def plans(self)->PlansClient:
        return PlansClient(self.__private_api_client)


    @property
    def contracts(self)->ContractsClient:
        return ContractsClient(self.__private_api_client)


    @property
    def meters(self)->MetersClient:
        return MetersClient(self.__private_api_client)


    @property
    def invoices(self)->InvoicesClient:
        return InvoicesClient(self.__private_api_client)

    @property
    def events(self)->EventsClient:
        return EventsClient(self.__private_api_client)

    def __login(self, refresh_token: str):
        auth_api = AuthApi(self.__public_api_client)
        login_request = LoginRequestSchema(refreshToken=refresh_token)
        refresh_response = auth_api.login(login_request)

        self.__access_token = refresh_response.access_token



# flake8: noqa

# import apis into api package
from openapi_client.api.auth_api import AuthApi
from openapi_client.api.contracts_api import ContractsApi
from openapi_client.api.customers_api import CustomersApi
from openapi_client.api.events_api import EventsApi
from openapi_client.api.invoices_api import InvoicesApi
from openapi_client.api.meters_api import MetersApi
from openapi_client.api.plans_api import PlansApi




from datetime import datetime

from openapi_client.api.contracts_api import ContractsApi
from openapi_client.api_client import ApiClient
from openapi_client.models.create_contract_request_schema import \
    CreateContractRequestSchema


class ContractsClient:
    __contracts_client: ContractsApi = None

    def __init__(self, api_client: ApiClient):
        self.__contracts_client = ContractsApi(api_client)

    def get(self, contract_id: str):
        return self.__contracts_client.get_contract(contract_id)
    
    def list(self, limit: int = None, cursor: int = None):
        return self.__contracts_client.list_contracts(limit=limit, cursor=cursor)

    def create(
        self,
        start_date: datetime,
        end_date: datetime,
        customer_id: str,
        plan_id: str
    ):
        create_contract_request = CreateContractRequestSchema(
            start_date=start_date,
            end_date=end_date,
            customer_id=customer_id,
            plan_id=plan_id
        )
        return self.__contracts_client.create_contract(create_contract_request)

    def delete(self, id: str):
        return self.__contracts_client.delete_contract(id)


from typing import List

from openapi_client.api.customers_api import CustomersApi
from openapi_client.api_client import ApiClient
from openapi_client.models.create_customer_request_schema import \
    CreateCustomerRequestSchema
from openapi_client.models.update_customer_request_schema import \
    UpdateCustomerRequestSchema


class CustomersClient:
    __customers_client: CustomersApi = None

    def __init__(self, api_client: ApiClient):
        self.__customers_client = CustomersApi(api_client)

    def get(self, customer_id: str):
        return self.__customers_client.get_customer(customer_id)
    
    def list(self, cursor: str = None, limit: int = None):
        return self.__customers_client.list_customers(limit=limit, cursor=cursor)

    def create(self, name: str, alias: str):
        create_customer_request = CreateCustomerRequestSchema(name=name, alias=alias)
        return self.__customers_client.create_customer(create_customer_request)

    def update(self, id: str, name: str = None, alias: str = None):
        update_customer_request = UpdateCustomerRequestSchema(name=name, alias=alias)
        return self.__customers_client.update_customer(id, update_customer_request)

    def delete(self, id: str):
        return self.__customers_client.delete_customer(id)


from setuptools import find_packages, setup


def read_requirements():
    with open('requirements.txt') as req:
        return req.read().splitlines()

setup(
    packages=find_packages(exclude=['*test']),
    install_requires=read_requirements(),    
    py_modules=['vayu', 'vayu_consts'],
)




# coding: utf-8

"""
    Vayu API

    The Vayu API is a RESTful API that allows you to submit events for processing and storage & manage billing related entities.           The API is secured using the Bearer Authentication scheme with JWT tokens.           To obtain a JWT token, please contact Vayu at team@withvayu.com

    The version of the OpenAPI document: 1.0.0
    Contact: dev@withvayu.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AggregationOperator(str, Enum):
    """
    The aggregation method defines how the events should be summed to represent a usage value.
    """

    """
    allowed enum values
    """
    COUNT = 'Count'
    SUM = 'Sum'
    DISTINCT = 'Distinct'
    MAX = 'Max'
    MIN = 'Min'
    AVERAGE = 'Average'
    FIRST = 'First'
    LAST = 'Last'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AggregationOperator from a JSON string"""
        return cls(json.loads(json_str))


